.. _bijwerkingen:


.. raw:: html

    <br>
    <center>

bijwerkingen clozapine
======================

.. raw:: html

    </center>
    <br>


Table 10. Adverse Reactions (≥2%) Reported in CLOZARIL-treated Patients (N=842) Across all CLOZARIL Studies (excluding the 2-year InterSePTTM Study)

Body System Adverse Reaction*

CLOZARIL

N=842

Percentage of Patients

Body System Adverse Reaction*

Central Nervous System:

1) Drowsiness/Sedation 39
2) Dizziness/Vertigo 19
3) Headache 7
4) Tremor 6
5) Syncope 6
6) Disturbed Sleep/Nightmares 4
7) Restlessness 4
8) Hypokinesia/Akinesia 4
9) Agitation 4
10) Seizures (convulsions) 3†
11) Rigidity 3
12) Akathisia 3
13) Confusion 3
14) Fatigue 2
15) Insomnia 2

Cardiovascular:

16) Tachycardia 25†
17) Hypotension 9
18) Hypertension 4

Gastrointestinal:

19) Constipation 14
20) Nausea 5
21) Abdominal Discomfort/Heartburn 4
22) Nausea/Vomiting3
23) Vomiting 3
24) Diarrhea 2

Urogenital:

25) Urinary Abnormalities 2

Autonomic Nervous System:

26) Salivation 31
27) Sweating 6
28) Dry Mouth 6
29) Visual Disturbances 5

Skin:

30) Rash 2

Hemic/Lymphatic:

31) Leukopenia/Decreased WBC/Neutropenia 3

Miscellaneous:

32) Fever 4
33) Weight Gain 5

†Rate based on population of approximately 1700 exposed during premarket
clinical evaluation of CLOZARIL.
